tests.test_decorations module — pydevDAG 1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- tests »
- tests package »

# tests.test_decorations module

## tests.test_decorations

Tests graph decorations.

class `tests.test_decorations.` `TestGraphNodeDecorations`

  Bases: `object`

  Test decorating structure graphs.

  `test_devpath`()

    Test that the value of DEVPATH is the same as the key of the node.

class `tests.test_decorations.` `TestNodeDecorating`

  Bases: `object`

  Test actually decorating a graph.

  `test_decorating_edges`()

    Test that decorating actually sets the proper value.

  `test_decorating_nodes`()

    Test that decorating actually sets the proper value.

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- tests »
- tests package »